/*

    ThermostatQA - test framework for Thermostat Monitoring Tool

    Copyright 2013 Red Hat, Inc.

This file is part of ThermostatQA

ThermostatQA is distributed under the GNU General Public License,
version 2 or any later version (with a special exception described
below, commonly known as the "Classpath Exception").

A copy of GNU General Public License (GPL) is included in this
distribution, in the file COPYING.

Linking ThermostatQA code with other modules is making a combined work
based on ThermostatQA.  Thus, the terms and conditions of the GPL
cover the whole combination.

As a special exception, the copyright holders of ThermostatQA give you
permission to link this code with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on ThermostatQA code.  If you modify ThermostatQA, you may
extend this exception to your version of the software, but you are
not obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/



package org.thermostat.qa.framework;

import java.io.IOException;
import java.util.List;



import org.thermostat.qa.reporter.FileUtils;
import org.thermostat.qa.testsuites.OutputMessagesTest;
import org.thermostat.qa.testsuites.CliClientSmokeTest;

/**
 * Class ThermostatOutputTextGenerator
 * contains methods for generating the output texts needed for
 * <ul>
 * <li> CliClientSmokeTest
 * <li> OutputMessagesTest
 * </ul> testsuites automatically.
 */
public class ThermostatOutputTextsGenerator extends ThermostatUtilities
{

   /**
    * Method getThermostatOutputForParams
    * runs thermostat with given parameters in a new process
    * returns the process output.
    * 
    * @param flags
    * @return
    * @throws IOException
    */
    public List<String> getThermostatOutputForParams(String... flags) throws IOException
    {
        Process process = runThermostatInNewProcess(flags);
        return readProcessOutput(process);
    }
    
    /**
     * Method writeTextsForOutputMessagesTest
     * gets output for all the possible commands that appear
     * in OutputMessagesTest and writes the output into text
     * files in the <code>outputtext/version?</code> directory
     * for current version of the thermostat outputs.
     * 
     * @throws IOException
     */
    public void writeTextsForOutputMessagesTest() throws IOException
    {
        List<String> output = null;
        String fileName = null;
        String[][] allflags = OutputMessagesTest.allflags;     
        String[] allscripts = CliClientSmokeTest.allscripts;
        
        int i=0;
        int maxi = allflags.length + allscripts.length;
        for(String[] flags : allflags)
        {
            i++;
            output = getThermostatOutputForParams(flags);
            fileName = getFileNameFromCommand(flags);
            if(output != null)
            {
                FileUtils.writeTextFile(fileName, output);
                System.out.println(fileName+" written (file "+i+" from "+maxi+")");
            }else{
                System.out.println(fileName+" NULL OUTPUT, NOT WRITTEN (file "+i+" from "+maxi+")");
            }
        }        
        for(String s : allscripts)
        {
            i++;
            output = runCommandsInThermostatShell(s);
            fileName = getFileNameFromScriptName(s);
            if(output != null)
            {
                FileUtils.writeTextFile(fileName, output);
                System.out.println(fileName+" written (file "+i+" from "+maxi+")");
            }else{
                System.out.println(fileName+" NULL OUTPUT, NOT WRITTEN (file "+i+" from "+maxi+")");
            }
        }       
        
    }
    
    /**
     * Method getFileNameFromCommand transforms
     * given parameters into txt file name, e.g.:
     * thermostat help agent ... thermostat_help_agent.txt
     * 
     * @param flags
     * @return
     */
    public String getFileNameFromCommand(String... flags)
    {
        StringBuffer sb = new StringBuffer();
        sb.append("outputtexts/");
        sb.append(this.configuration.getThermostatVersion());
        sb.append("/thermostat");
        if(flags != null)
        {
            for(String s : flags)
            {
                sb.append("_");
                sb.append(s);
            }
        }
        String str = sb.toString() + ".txt";
        
        return str;
    }
    
    public String getFileNameFromScriptName(String scriptname)
    {
        StringBuffer sb = new StringBuffer();
        sb.append("outputtexts/");
        sb.append(this.configuration.getThermostatVersion());
        sb.append("/output_of_");
        return sb.toString()+scriptname;
    }
    
    /**
     * Method main
     * reads current configuration from test.properties, and
     * generates the texts used in OutputMessagesTest.
     * 
     * @param args
     * @throws IOException
     */
    public static void main(String[] args) throws IOException
    {
        ThermostatOutputTextsGenerator totg = new ThermostatOutputTextsGenerator();
        totg.setConfigurationFromProperties(null);
        totg.writeTextsForOutputMessagesTest();
    }
}
